@@ -19,6 +19,9 @@ private:
     Ui::CleaN900 *ui;
 
 private slots:
+    void on_pushApp_clicked();
+    void on_pushBat_clicked();
+    void on_pushCard_clicked();
     void on_pushOpt_clicked();
     void on_pushRam_clicked();
     void on_pushMydocs_clicked();
